@@ -24,14 +24,14 @@ static QColor inputToColor(const QVariant &v)
 
 static QString rgbaString(const QColor &c)
 {
-    return QLatin1String("rgba(")
-           + QString::number(c.red()) + QLatin1String(", ")
-           + QString::number(c.green()) + QLatin1String(", ")
-           + QString::number(c.blue()) + QLatin1String(", ")
-           + QString::number(c.alphaF()) + QLatin1Char(')');
+    return QLatin1String("rgba(") + QString::number(c.red()) + QLatin1String(", ") + QString::number(c.green()) + QLatin1String(", ")
+        + QString::number(c.blue()) + QLatin1String(", ") + QString::number(c.alphaF()) + QLatin1Char(')');
 }
 
-#define COLOR_PROP(name) if (property == QLatin1String(#name)) { return object.name(); }
+#define COLOR_PROP(name)                                                                                                                                       \
+    if (property == QLatin1String(#name)) {                                                                                                                    \
+        return object.name();                                                                                                                                  \
+    }
 
 GRANTLEE_BEGIN_LOOKUP(QColor)
 COLOR_PROP(red)
@@ -106,7 +106,7 @@ ColorMixTag::~ColorMixTag() = default;
 
 Grantlee::Node *ColorMixTag::getNode(const QString &tagContent, Grantlee::Parser *p) const
 {
-    Q_UNUSED(p);
+    Q_UNUSED(p)
     const auto parts = smartSplit(tagContent);
     if (parts.size() != 4 && parts.size() != 6) {
         throw Grantlee::Exception(Grantlee::TagSyntaxError, QStringLiteral("colormix tag needs 3 or 5 arguments"));
